@@ -455,6 +455,7 @@ int hts_parse_opt_list(htsFormat *opt, const char *str);
 The input character may be either an IUPAC ambiguity code, '=' for 0, or
 '0'/'1'/'2'/'3' for a result of 1/2/4/8.  The result is encoded as 1/2/4/8
 for A/C/G/T or combinations of these bits for ambiguous bases.
+Additionally RNA U is treated as a T (8).
 */
 HTSLIB_EXPORT
 extern const unsigned char seq_nt16_table[256];
@@ -489,7 +490,7 @@ const char *hts_version(void);
 // Immediately after release, bump ZZ to 90 to distinguish in-development
 // Git repository builds from the release; you may wish to increment this
 // further when significant features are merged.
-#define HTS_VERSION 102000
+#define HTS_VERSION 102200
 
 /*! @abstract Introspection on the features enabled in htslib
  *
@@ -1517,6 +1518,14 @@ static inline int hts_bin_level(int bin) {
     return l;
 }
 
+/**************************************
+ * Exposing the CRC32 implementation  *
+ * Either from zlib or libdeflate.    *
+ *************************************/
+HTSLIB_EXPORT
+uint32_t hts_crc32(uint32_t crc, const void *buf, size_t len);
+
+
 //! Compute the corresponding entry into the linear index of a given bin from
 //! a binning index
 /*!
@@ -1534,6 +1543,13 @@ static inline int hts_bin_bot(int bin, int n_lvls)
     return (bin - hts_bin_first(l)) << (n_lvls - l) * 3;
 }
 
+/// Compute the (0-based exclusive) maximum position covered by a binning index
+static inline hts_pos_t hts_bin_maxpos(int min_shift, int n_lvls)
+{
+    hts_pos_t one = 1;
+    return one << (min_shift + n_lvls * 3);
+}
+
 /**************
  * Endianness *
  **************/
